@@ -204,7 +204,7 @@ my $configure_php=sub {
       my $done=0;my $gittry=0;
       while ($done==0) {
          ($stdout,$stderr)=$handle->cmd($sudo.
-            'git clone git://sourceware.org/git/bzip2.git',
+            'git clone git://sourceware.org/git/bzip2.git',300,
             '__display__');
          if (++$gittry>5) {
             print "\n\n   FATAL ERROR: $stderr\n\n";
@@ -248,7 +248,7 @@ my $configure_php=sub {
       my $done=0;my $gittry=0;
       while ($done==0) {
          ($stdout,$stderr)=$handle->cmd($sudo.
-            'git clone https://gitlab.gnome.org/GNOME/libxml2.git',
+            'git clone https://gitlab.gnome.org/GNOME/libxml2.git',300,
             '__display__');
          if (++$gittry>5) {
             print "\n\n   FATAL ERROR: $stderr\n\n";
@@ -329,7 +329,7 @@ my $configure_php=sub {
       my $done=0;my $gittry=0;
       while ($done==0) {
          ($stdout,$stderr)=$handle->cmd($sudo.
-            'git clone --recursive https://github.com/openssl/openssl.git',
+            'git clone --recursive https://github.com/openssl/openssl.git',300,
             '__display__');
          if (++$gittry>5) {
             print "\n\n   FATAL ERROR: $stderr\n\n";
@@ -431,7 +431,7 @@ my $configure_php=sub {
       my $done=0;my $gittry=0;
       while ($done==0) {
          ($stdout,$stderr)=$handle->cmd($sudo.
-            'git clone https://github.com/Kitware/CMake.git',
+            'git clone https://github.com/Kitware/CMake.git',300,
             '__display__');
          if (++$gittry>5) {
             print "\n\n   FATAL ERROR: $stderr\n\n";
@@ -467,7 +467,7 @@ my $configure_php=sub {
       my $done=0;my $gittry=0;
       while ($done==0) {
          ($stdout,$stderr)=$handle->cmd($sudo.
-            'git clone https://github.com/nih-at/libzip.git',
+            'git clone https://github.com/nih-at/libzip.git',300,
             '__display__');
          if (++$gittry>5) {
             print "\n\n   FATAL ERROR: $stderr\n\n";
@@ -532,7 +532,7 @@ $stdout='rel-1-6-1';
       while ($done==0) {
          ($stdout,$stderr)=$handle->cmd($sudo.
             'git clone https://github.com/jedisct1/libsodium 2>&1',
-            '__display__');
+            300,'__display__');
          if (++$gittry>5) {
             print "\n\n   FATAL ERROR: $stderr\n\n";
             cleanup();
@@ -587,7 +587,7 @@ $stdout='rel-1-6-1';
       my $done=0;my $gittry=0;
       while ($done==0) {
          ($stdout,$stderr)=$handle->cmd($sudo.
-            'git clone https://github.com/php/php-src.git',
+            'git clone https://github.com/php/php-src.git',300,
             '__display__');
          if (++$gittry>5) {
             print "\n\n   FATAL ERROR: $stderr\n\n";
